@@ -16,10 +16,9 @@ from __future__ import annotations
 from dataclasses import dataclass
 from typing import Any, List, Mapping
 
-from card_framework import enum_field, list_field, standard_field
+from card_framework import enum_field, list_field, standard_field, AutoNumber
 from dataclasses_json import LetterCase, dataclass_json
 
-from ..enums import AutoNumber, LoadIndicator
 from ..widget import Widget
 
 
@@ -30,9 +29,15 @@ class Action(Widget):
     UNSPECIFIED = 'UNSPECIFIED'
     OPEN_DIALOG = 'OPEN_DIALOG'
 
+  class LoadIndicator(AutoNumber):
+    """LoadIndicator
+    """
+    SPINNER = 'SPINNER'
+    NONE = 'NONE'
+
   function: str = standard_field(default='')
   parameters: List[ActionParameter] = list_field()
-  load_indicator: LoadIndicator = standard_field()
+  load_indicator: LoadIndicator = enum_field()
   persist_values: bool = standard_field()
   interaction: Interaction = enum_field()
 
